Module input

Utilities for constructing lexers.

This module conntains the InputStream trait, which can be implemented for input streams, i.e. streams that return characters. This trait has already been implemented for Reader and ByteReader.

The InputStream trait provides many useful utility methods for reading characters and the corresponding Spans from the input stream.

Traits

InputStream
Trait for input streams.