Struct Reader

pub struct Reader<T, const BUFFER_SIZE: usize = BYTE_BUFFER_SIZE> { /* private fields */ }
A generic UTF-8 character reader for lexers.

The generic parameter BUFFER_SIZE specifies the size of the internal buffer of Reader.

Reader always tries to read UTF-8 characters from the stream. If there are no valid UTF-8 characters, Reader will return a fatal error (Error::Fatal).

Implementations

Source

impl<T, const BUFFER_SIZE: usize> Reader<T, BUFFER_SIZE>

pub fn new(reader: T, file_type: FileType) -> Self

Creates a new reader with the given inner reader and file type.

Source

impl<T> Reader<T>

pub fn into_inner(self) -> T

Converts the reader into its inner reader.

Source

impl Reader<File>

pub fn from_path<P>(path: P) -> Result<Self>
where P: AsRef<Path> + Clone,

Creates a new reader from the file at the given path.

Source

impl Reader<Stdin>

pub fn from_stdin() -> Self

Creates a new reader from the standard input.